The highest tagged major version is
v2 .
Discover Packages
github.com/gounix/goregistry
package
module
Version:
v1.0.11
Opens a new window with list of versions in this module.
Published: Jul 28, 2026
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type AnnotationsT struct {
Created time .Time `json:"org.opencontainers.image.created"`
Url string `json:"org.opencontainers.image.url"`
Version string `json:"org.opencontainers.image.version"`
}
type BlobT struct {
Created time .Time `json:"created"`
}
type ConfigT struct {
MediaType string `json:"mediaType"`
Digest string `json:"digest"`
}
type ManifestT struct {
Digest string `json:"digest"`
Platform PlatformT `json:"platform"`
Annotations AnnotationsT `json:"annotations"`
}
type ManifestsT struct {
MediaType string `json:"mediaType"`
Manifest []ManifestT `json:"manifests"`
}
type PlatformT struct {
Architecture string `json:"architecture"`
Os string `json:"os"`
}
type SingleT struct {
MediaType string `json:"mediaType"`
Config ConfigT `json:"config"`
}
type TokenRespT struct {
Token TokenT `json:"token"`
AccessToken string `json:"access_token"`
ExpiresIn int64 `json:"expires_in"`
IssuedAt time .Time `json:"issued_at"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.